@@ -134,6 +134,14 @@ class ConfigValidator:
             print(e)
             cls.raise_exc(input)
 
+    @classmethod
+    def locale(cls, input):
+        try:
+            return Locale[input.upper()]
+        except Exception as e:
+            print(e)
+            cls.raise_exc(input)
+
     @classmethod
     def str_list(cls, input):
         if type(input) is not list:
