@@ -23,15 +23,21 @@ from arjuna.core.value import Value
 
 class DataRecord:
 
-    def __init__(self, *vargs, **kwargs):
-        self.__indexed = tuple([Value(v) for v in vargs])
-        self.__named = types.MappingProxyType({i.lower(): Value(j) for i, j in kwargs.items()})
+    def __init__(self, *vargs, process=True, **kwargs):
+        self.__indexed = None
+        self.__named = None
+        if process:
+            self.__indexed = tuple(vargs)
+            self.__named = types.MappingProxyType({i.lower(): j for i, j in kwargs.items()})
+        else:
+            self.__indexed = tuple()
+            self.__named = types.MappingProxyType({}) 
 
     def __getitem__(self, i):
         if type(i) is int:
             return self.__indexed[i]
         else:
-            return self.__named[i]
+            return self.__named[i.lower()]
 
     def __getattr__(self, i):
         if type(i) is str and not i.startswith('__'):
@@ -39,6 +45,11 @@ class DataRecord:
         else:
             super().__getattr__(i)
 
+    def should_exclude(self):
+        if "exclude" in self.__named:
+            if self.__named["exclude"].lower() in {"y","yes","true","1"}:
+                return True
+
     def value_named(self, name):
         return self.__named[name.lower()]
 
@@ -56,13 +67,13 @@ class DataRecord:
             parts.append("<empty>")
         else:
             for i,v in enumerate(self.indexed_values()):
-                parts.append("[{}] {}".format(i, v.as_string()))
+                parts.append("[{}] {}".format(i, v))
         parts.append("Named")
         if not self.named_values():
             parts.append("<empty>")
         else:
             for i,v in self.named_values().items():
-                parts.append("[{}] {}".format(i, v.as_string()))
+                parts.append("[{}] {}".format(i, v))
         return "\n".join(parts)
 
     def is_empty(self):
@@ -78,11 +89,30 @@ class DataRecord:
         return key.lower() in self.__named
 
     def string(self, key):
-        return self.value_named(key).as_string()
+        return self.value_named(key)
 
     def has_index(self, index):
         return len(self.__indexed) > index
 
+    def __str__(self):
+        if not self.indexed_values and not self.named_values:
+            return ""
+        if self.indexed_values:
+            indexed = " Indexed:{}".format(str([i for i in self.indexed_values]))
+        else:
+            indexed = ""
+        if self.named_values:
+            named =  " Named:{{{}}}".format(', '.join(['{0}={1}'.format(k, v) for k,v in self.named_values.items()]))
+        else:
+            named = ""
+        return "Data->{}{}".format(indexed, named)
+
+
+class DummyDataRecord(DataRecord):
+    
+    def __init__(self):
+        super().__init__(process=False)
+
 class ListDataRecord:
 
     def __init__(self, data_record):
@@ -92,11 +122,6 @@ class ListDataRecord:
     def record(self):
         return self.__data_record
 
-class DummyDataRecord(ListDataRecord):
-    
-    def __init__(self):
-        super().__init__(None)
-
 
 class MapDataRecord:
 
