@@ -19,22 +19,36 @@ limitations under the License.
 
 import abc
 
-from arjuna.lib.reader.excel import *
+from arjuna.core.reader.excel import *
 from .record import *
-
+from arjuna.core.adv.types import CIStringDict
 
 class ContextualDataReference(metaclass=abc.ABCMeta):
 
+    def __init__(self):
+        self.map = {}
+
     @abc.abstractmethod
     def record_for(self, context):
         pass
 
+    def update(self, data_reference):
+        for context, record in data_reference.map.items():
+            if context not in self.map:
+                self.map[context] = CIStringDict()
+            self.map[context].update(record.named_values)
+
+    def record_for(self, context):
+        if context.lower() in self.map:
+            return self.map[context.lower()]
+        else:
+            raise Exception("Context key {} not found in data reference: {}.".format(context, self.__class__.__name__))
+
 class __ExcelDataReference(ContextualDataReference):
-    def __init__(self, path, key_column=None):
-        self.map = {}
+    def __init__(self, path):
+        super().__init__()
         self.path = path
-        self.key_column = key_column
-        if (path.lower().ends_with("xls")):
+        if (path.lower().endswith("xls")):
             self.reader = ExcelRow2ArrayReader(path)
         else:
             raise Exception("Unsupported file format for Excel reading.")
@@ -46,25 +60,26 @@ class __ExcelDataReference(ContextualDataReference):
         pass
 
     def record_for(self, context):
-        if context.lower() in self.map:
-            return self.map[context.lower()]
-        else:
+        try:
+            return super().record_for(context)
+        except:
             raise Exception("{} at {} does not contain {} context key.".format(self.__class__.__name__, self.path, context))
 
+
 class ExcelRowDataReference(__ExcelDataReference):
 
     def __init__(self, path):
         super().__init__(path)
 
     def _populate(self):
-        headers = self.reader.next()[1:]
+        names = self.reader.headers[1:]
         while True:
             try:
                 data_record = self.reader.next()
             except StopIteration:
                 break
             else:
-                self.map[data_record[0].lower()] = DataRecord(zip(headers, data_record[1:]))
+                self.map[data_record[0].lower()] = DataRecord(**dict(zip(names, data_record[1:])))
         self.reader.close()
 
 
@@ -74,15 +89,17 @@ class ExcelColumnDataReference(__ExcelDataReference):
         super().__init__(path)
 
     def _populate(self):
-        contexts = self.reader.next()[1:]
-        self.map = {i: {} for i in contexts}
+        contexts = self.reader.headers[1:]
+        cmap = {i: {} for i in contexts}
         while True:
             try:
                 data_record = self.reader.next()
             except StopIteration:
                 break
             else:
-                header = data_record[0]
+                name = data_record[0]
                 for index, context in enumerate(contexts):
-                    self.map[context][header] = data_record[index]
+                    cmap[context][name] = data_record[index+1]
         self.reader.close()
+        for context, kv in cmap.items():
+            self.map[context.lower()] = DataRecord(**kv)
