@@ -22,6 +22,7 @@ import pytest
 import sys
 
 from arjuna.core.enums import ReportFormat
+from arjuna.core.value import Value
 
 class TestRunner:
     import sys
@@ -31,13 +32,14 @@ class TestRunner:
     def __init__(self):
         from arjuna import Arjuna
         from arjuna.core.enums import ArjunaOption
-        self.__project_dir = Arjuna.get_ref_config().get_arjuna_option_value(ArjunaOption.PROJECT_ROOT_DIR).as_str()
+        self.__project_dir = Arjuna.get_ref_config().arjuna_options.value(ArjunaOption.PROJECT_ROOT_DIR)
         # import sys
         # sys.path.insert(0, self.__project_dir + "/..")
-        self.__tests_dir = Arjuna.get_ref_config().get_arjuna_option_value(ArjunaOption.PROJECT_TESTS_DIR).as_str()
-        self.__xml_path = os.path.join(Arjuna.get_ref_config().get_arjuna_option_value(ArjunaOption.PROJECT_RUN_REPORT_XML_DIR).as_str(), "report.xml")
-        self.__html_path = os.path.join(Arjuna.get_ref_config().get_arjuna_option_value(ArjunaOption.PROJECT_RUN_REPORT_HTML_DIR).as_str(), "report.html")
-        self.__report_formats = Arjuna.get_ref_config().get_arjuna_option_value(ArjunaOption.PROJECT_REPORT_FORMATS).as_enum_list(ReportFormat)
+        self.__tests_dir = Arjuna.get_ref_config().arjuna_options.value(ArjunaOption.PROJECT_TESTS_DIR)
+        self.__xml_path = os.path.join(Arjuna.get_ref_config().arjuna_options.value(ArjunaOption.PROJECT_RUN_REPORT_XML_DIR), "report.xml")
+        self.__html_path = os.path.join(Arjuna.get_ref_config().arjuna_options.value(ArjunaOption.PROJECT_RUN_REPORT_HTML_DIR), "report.html")
+        self.__report_formats = Arjuna.get_ref_config().arjuna_options.value(ArjunaOption.PROJECT_REPORT_FORMATS)
+        # self.__report_formats = Value.as_enum_list(rfmts, ReportFormat)
         res_path = os.path.abspath(os.path.join(os.path.dirname(os.path.realpath(__file__)), "../res"))
         pytest_ini_path = res_path + "/pytest.ini"
 
@@ -56,7 +58,7 @@ class TestRunner:
     def load_all_tests(self):
         self.__pytest_args.insert(0, self.tests_dir)
 
-    def load_tests_from_pickers(self, *, cm=None, im=None, ct=None, it=None):  
+    def load_tests_from_pickers(self, *, im=None, em=None, it=None, et=None):  
 
         def process_modules(ms):
             ms = [m.replace(".py", "").replace("*","").replace("/", " and ").replace("\\", " and ") for m in ms]
@@ -66,9 +68,9 @@ class TestRunner:
 
         k_flag = False
 
-        if im:            
-            im = process_modules(im)
-            k_args.append(" and ".join(["not " + m for m in im]))
+        if em:            
+            em = process_modules(em)
+            k_args.append(" and ".join(["not " + m for m in em]))
             k_flag = True
 
         # if ic:
@@ -76,15 +78,15 @@ class TestRunner:
         #     k_args.append(prefix + " and ".join(["not " + c for c in ic]))
         #     k_flag = True
 
-        if it:
+        if et:
             prefix = k_flag and " and " or ""
-            k_args.append(prefix + " and ".join(["not " + c for c in it]))
+            k_args.append(prefix + " and ".join(["not " + c for c in et]))
             k_flag = True
 
-        if cm:
+        if im:
             prefix = k_flag and " and " or ""            
-            cm = process_modules(cm)
-            k_args.append(prefix + " or ".join(cm))
+            cm = process_modules(im)
+            k_args.append(prefix + " or ".join(im))
             k_flag = True
 
         # if cc:
@@ -92,16 +94,16 @@ class TestRunner:
         #     k_args.append(prefix + " or ".join(cc))
         #     k_flag = True
 
-        if ct:
+        if it:
             prefix = k_flag and " and " or "" 
-            k_args.append(prefix + " or ".join(ct))
+            k_args.append(prefix + " or ".join(it))
             k_flag = True
 
         if k_flag:
             self.__test_args.append("-k " + "".join(k_args))
         
   
-    def run(self, *, only_enumerate):
+    def run(self, *, dry_run):
         from arjuna import Arjuna
         from arjuna.core.enums import ArjunaOption
 
@@ -116,9 +118,13 @@ class TestRunner:
         self.__pytest_args.extend(pytest_report_args)
         self.__pytest_args.extend(self.__test_args)
 
-        if only_enumerate:
+        if dry_run:
             self.__pytest_args.append("--collect-only")
 
         os.chdir(self.__project_dir)
         print("Executing pytest with args: {}".format(" ".join(self.__pytest_args)))
-        pytest.main(self.__pytest_args)
+
+
+        pytest_retcode = pytest.main(self.__pytest_args)
+        import sys
+        sys.exit(pytest_retcode)
