@@ -77,23 +77,29 @@ SCOPE_MAP = {
     "session"  : "session"
 }
 
-class Resources:
+class Space:
 
     def __init__(self, pytest_request):
         vars(self)['_request'] = pytest_request
 
     def __getitem__(self, name):
         scopes = LOOKUP_ORDER[self._request.scope]
+        from arjuna import Arjuna
         for scope in scopes:
+            Arjuna.get_logger().debug("Space: Getting value for {} from {} scope".format(name, scope))
             try:
                 container = getattr(self._request, SCOPE_MAP[scope])
                 return getattr(container, name)
             except Exception as e:
+                Arjuna.get_logger().debug("Space: No value for {} in {} scope".format(name, scope))
                 continue
         raise Exception("Attribute with name >>{}<< does not exist in request scope for {}".format(name, scopes))
 
+    def _get_container_for_scope(self):
+        return getattr(self._request, SCOPE_MAP[self._request.scope])
+
     def __setitem__(self, name, value):
-        container = getattr(self._request, SCOPE_MAP[self._request.scope])
+        container = self._get_container_for_scope()
         setattr(container, name, value)
 
     def __getattr__(self, name):
@@ -101,91 +107,122 @@ class Resources:
             return self[name]
 
     def __setattr__(self, name, value):
-        container = getattr(self._request, SCOPE_MAP[self._request.scope])
+        container = self._get_container_for_scope()
+        from arjuna import Arjuna
+        Arjuna.get_logger().debug("Space: Setting {}={} in {} scope".format(name, value, self._request.scope))
         setattr(container, name, value)
 
     @property
     def raw_request(self):
         return self._request
 
+class ModuleSpace(Space):
+
+    def __init__(self, pytest_request):
+        super().__init__(pytest_request)
+
+    def _get_container_for_scope(self):
+        return getattr(self._request, "module")
+
+class Module:
+
+    def __init__(self, py_request):
+        self._space = ModuleSpace(py_request)
+
+    @property
+    def space(self):
+        return self._space
+
 class My:
 
     def __init__(self):
-        self.__data = None
-        self.__info = None
-        self.__resources = None
-        self.__handler = None
-        self.__qual_name = None
-        self.__request =  None
-        self.__shared_objects = None
-        self.__asserter = Asserter() #unittest.TestCase('__init__')
+        self._data = None
+        self._info = None
+        self._handler = None
+        self._qual_name = None
+        self._request =  None
+        self._shared_objects = None
+        self._asserter = Asserter() #unittest.TestCase('__init__')
+        self._space = None
+        self._module = None
+    
+    @property
+    def data_refs(self):
+        from arjuna import Arjuna
+        return Arjuna.get_data_references()
+
+    @property
+    def module(self):
+        return self._module
 
     @property
     def data(self):
-        return self.__data
+        return self._data
 
     @property
     def asserter(self):
-        return self.__asserter
-
-    @property
-    def module_shared_space(self):
-        return self.__request.module.shared_space
+        return self._asserter
 
     @data.setter
     def data(self, record):
-        self.__data = record
+        self._data = record
+
+    @property
+    def space(self):
+        return self._space
 
     def set_req_obj(self, pytest_request):
-        self.__request = pytest_request
-        self.__info = Info(pytest_request)
-        self.__resources = Resources(pytest_request)
-        if pytest_request.scope in {"session", "module", "class"}:
-            try:
-                getattr(pytest_request.module, "shared_space")
-                print("old", pytest_request)
-            except:
-                print("new", pytest_request)
-                pytest_request.module.shared_space = SharedObjects()
+        self._request = pytest_request
+        self._info = Info(pytest_request)
+        self._space = Space(pytest_request)
+        if pytest_request.scope in {"function"}:
+            if not self._module:
+                self._module = Module(pytest_request)
+                
 
     @property
     def info(self):
-        return self.__info
+        return self._info
 
     @property
     def resources(self):
-        return self.__resources
+        return self._resources
 
     @property
     def raw_request(self):
-        return self.__request
+        return self._request
 
 def tc(cls):
     setattr(cls, 'get_test_qual_name', get_test_qual_name)
     return cls
 
-def call_func(func, my, request, *args, **kwargs):
+def call_func(func, request, data=None, *args, **kwargs):
     from arjuna import Arjuna
-    my.set_req_obj(request) 
-    qual_name = my.info.qual_name_with_data
-    Arjuna.get_logger().info("Begin test function: {}".format(qual_name))        
-    func(my, request, *args, **kwargs)
+    request_wrapper = My()
+    request_wrapper.set_req_obj(request)
+    qual_name = request_wrapper.info.qual_name_with_data
+    Arjuna.get_logger().info("Begin test function: {}".format(qual_name))  
+    if data:      
+        func(request=request_wrapper, data=data, *args, **kwargs)
+    else:
+        func(request=request_wrapper, *args, **kwargs)
     Arjuna.get_logger().info("End test function: {}".format(qual_name))
 
 def simple_dec(func):
+    func.__name__ = "check_" + func.__name__
+
     @functools.wraps(func)
-    def wrapper(my, request, *args, **kwargs):
-        my.handler = request
-        call_func(func, my, request, *args, **kwargs)
+    def wrapper(request, *args, **kwargs):
+        call_func(func, request, *args, **kwargs)
     return wrapper
 
+def repr_record(record):
+    return str(record)
+
 def test(f=None, *, id=None, resources=None, drive_with=None, exclude_if=None):
 
     # Check if @test is provided without arguments
     if f is not None:
-        my = My()
-        my.data = DummyDataRecord()
-        func = pytest.mark.parametrize('my', [my])(f) 
         return simple_dec(f)
 
     if resources:
@@ -213,17 +250,26 @@ def test(f=None, *, id=None, resources=None, drive_with=None, exclude_if=None):
                 my = My()
                 my.data = record
                 my_objects.append(my)
-            func = pytest.mark.parametrize('my', my_objects)(func) 
-        else:
-            my = My()
-            my.data = DummyDataRecord()
-            func = pytest.mark.parametrize('my', [my])(func) 
+            func = pytest.mark.parametrize('data', records, ids=repr_record)(func) 
+        # else:
+        #     my = My()
+        #     my.data = DummyDataRecord()
+        #     func = pytest.mark.parametrize('my', [my], ids=My.repr)(func) 
 
         @functools.wraps(orig_func)
-        def wrapper(my, request, *args, **kwargs):
+        def wrapper_without_data(request, *args, **kwargs):
             my.handler = request
-            call_func(func, my, request, *args, **kwargs)
-        return wrapper
+            call_func(func, request, *args, **kwargs)
+
+        @functools.wraps(orig_func)
+        def wrapper_with_data(request, data, *args, **kwargs):
+            my.handler = request
+            call_func(func, request, data, *args, **kwargs)
+
+        if drive_with:
+            return wrapper_with_data
+        else:
+            return wrapper_without_data
     
     return format_test_func
 
