@@ -40,8 +40,8 @@ class GuiAutomator(ElementContainer,Dispatchable):
         self.__econfig = ext_config
         self.__create_screenshots_dir()
         self.__main_window = None
-        self.__in_slomo = config.get_arjuna_option_value(ArjunaOption.GUIAUTO_SLOMO_ON).as_bool()
-        self.__slomo_interval = config.get_arjuna_option_value(ArjunaOption.GUIAUTO_SLOMO_INTERVAL).as_int()
+        self.__in_slomo = config.arjuna_options.value(ArjunaOption.GUIAUTO_SLOMO_ON)
+        self.__slomo_interval = config.arjuna_options.value(ArjunaOption.GUIAUTO_SLOMO_INTERVAL)
 
         from .webalert_handler import WebAlertHandler
         from .automator_conditions import GuiAutomatorConditions
@@ -50,7 +50,7 @@ class GuiAutomator(ElementContainer,Dispatchable):
         self.__conditions_handler = GuiAutomatorConditions(self)
         self.__view_handler = ViewContextHandler(self)
         self.__browser = None
-        self.__screenshots_dir = config.get_arjuna_option_value(ArjunaOption.PROJECT_RUN_SCREENSHOTS_DIR).as_str()
+        self.__screenshots_dir = config.arjuna_options.value(ArjunaOption.PROJECT_RUN_SCREENSHOTS_DIR)
 
         self.__source_parser = None
 
@@ -133,7 +133,7 @@ class GuiAutomator(ElementContainer,Dispatchable):
         return self.__conditions_handler
 
     def __create_screenshots_dir(self):
-        sdir = self.config.get_arjuna_option_value(ArjunaOption.PROJECT_RUN_SCREENSHOTS_DIR).as_str()
+        sdir = self.config.arjuna_options.value(ArjunaOption.PROJECT_RUN_SCREENSHOTS_DIR)
         if not os.path.isdir(sdir):
             os.makedirs(sdir)
 
@@ -169,21 +169,21 @@ class GuiAutomator(ElementContainer,Dispatchable):
         # if switch_view_context:
         #     self.view_handler.switch_to_view_context(switch_view_context)
 
-    def take_screenshot(self, name=None):
+    def take_screenshot(self, prefix=None):
         image_b64 = self.dispatcher.take_screenshot_as_base64()
         image = base64.b64decode(image_b64)
 
         ts = datetime.datetime.now().strftime("%Y-%m-%d-%H-%M-%S-%f")[:-3]
-        if name:
-            name = name.replace("..", "") + "-"
+        if prefix:
+            prefix = prefix.replace(".py", "").replace("..", "").replace("::",".").replace(":", ".").replace("/", ".").replace("\\", ".") + "-"
         else:
-            name = ""
-        file_name = "{}{}.png".format(name, ts)
+            prefix = ""
+        file_name = "{}{}.png".format(prefix, ts)
         fpath = os.path.join(self.screenshots_dir, file_name)
         f = open(fpath, "wb")
         f.write(image)
         f.close()
-        return "../screenshots/{}".format(file_name), image_b64
+        return file_name, image_b64
 
     def focus_on_main_window(self):
         self.main_window.focus()
