@@ -19,6 +19,7 @@ limitations under the License.
 
 import re
 import os
+import copy
 from lxml import etree, html
 from io import StringIO
 from collections import namedtuple
@@ -36,7 +37,67 @@ def empty_or_none(in_str):
     else:
         return in_str is None
 
-SourceContent = namedtuple('SourceContet', "all root inner text")
+class SourceNode:
+
+    def __init__(self, node):
+        self.__node = node
+
+    @property
+    def xml_node(self):
+        return self.__node
+
+    @property
+    def text(self):
+        return self.xml_node.text
+
+    def __str__(self):
+        return etree.tostring(self.xml_node, encoding=str)
+
+    def findall(self, *finders, stop_when_matched=False):
+        out = []
+        for finder in finders:
+            nodes = finder(self.xml_node)
+            out.extend(nodes)
+            if stop_when_matched:
+                if nodes:
+                    break
+        return out
+
+    def find(self, *finders, stop_when_matched=False):
+        matches = self.findall(*finders, stop_when_matched=stop_when_matched)
+        if matches:
+            return matches[0]
+        else:
+            return None
+
+    def find_keyvalue_texts(self, key_finder, value_finder):
+        key = self.find(key_finder).text
+        value = self.find(value_finder).text
+        return key,value
+    
+class SourceContent:
+
+    def __init__(self, all, root, inner, text):
+        self.__all = all
+        self.__root = root
+        self.__inner = inner
+        self.__text = text
+
+    @property
+    def all(self):
+        return self.__all
+
+    @property
+    def root(self):
+        return self.__root
+
+    @property
+    def inner(self):
+        return self.__inner
+
+    @property
+    def text(self):
+        return self.__text
 
 class ElementXMLSourceParser:
 
@@ -46,15 +107,23 @@ class ElementXMLSourceParser:
         self.__root_element = root_element
         self.__fpaths = []
         self.__content = None
+        self.__node = None
 
     @property
     def content(self):
         return self.__content
 
+    @property
+    def node(self):
+        return self.__node
+
     def load(self):
         raw_source = self.__raw_source
         parser = etree.HTMLParser(remove_comments=True)
         tree = etree.parse(StringIO(raw_source), parser)
+        # Done separately from above to retain all original content
+        self.__node = SourceNode(etree.parse(StringIO(raw_source), parser))
+        
         if self.__root_element == "body":
             body = tree.getroot().find('body')
             elem_node = list(body)[0]
@@ -124,12 +193,17 @@ class ElementXMLSourceParser:
 
 class MultiElementSource:
 
-    def __init__(self):
+    def __init__(self, instances):
         super().__init__()
-        self.__instances = None
-
-    def load(self, instances):
         self.__instances = instances
+        self.__content = SourceContent(all=self.get_full_content(), root=self.get_root_content(), inner=self.get_inner_content(), text=self.get_text_content())
+
+    @property
+    def content(self):
+        return self.__content
+
+    # def load(self, instances):
+    #     self.__instances = instances
 
     def get_full_content(self):
         return os.linesep.join([e.source.content.all for e in self.__instances])
