@@ -1,3 +1,22 @@
+'''
+This file is a part of Arjuna
+Copyright 2015-2020 Rahul Verma
+
+Website: www.RahulVerma.net
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+  http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+'''
+
 from selenium.webdriver.common.action_chains import ActionChains
 
 class DriverCommands:
@@ -73,11 +92,15 @@ class DriverCommands:
         driver.switch_to.parent_frame()
 
     @classmethod
-    def execute_javascript(cls, driver, script):
-        return driver.execute_script(script)
+    def execute_javascript(cls, driver, script, *args):
+        return driver.execute_script(script, *args)
 
     @classmethod
-    def take_screenshot(cls, driver):
+    def take_screenshot(cls, driver, file_path):
+        return driver.save_screenshot(file_path)
+
+    @classmethod
+    def take_screenshot_as_base64(cls, driver):
         return driver.get_screenshot_as_base64()
 
     @classmethod
@@ -131,4 +154,10 @@ class DriverCommands:
     def hover_on_element(cls, driver, webelement):
         chain = ActionChains(driver).move_to_element(webelement).perform()
 
+    @classmethod
+    def mouse_click_on_element(cls, driver, webelement):
+        chain = ActionChains(driver).click(webelement).perform()
 
+    @classmethod
+    def scroll_to_element(cls, driver, webelement):
+        cls.execute_javascript(driver, "arguments[0].scrollIntoView(true);", webelement)
