@@ -18,6 +18,7 @@ limitations under the License.
 '''
 
 from .gui import *
+from arjuna.interact.gui.auto.finder.emd import GuiElementMetaData
 
 class Page(AppContent):
 
@@ -27,16 +28,61 @@ class Page(AppContent):
         self.app.ui = self
         self._load(*args, **kwargs)
 
-class Widget(AppContent):
+class Section(AppContent):
 
-    def __init__(self, page, *args, label=None, **kwargs):
-        super().__init__(automator=page.automator, label=label, page=page)   
-        self.__page = page
+    def __init__(self, gui, *args, root_element_locators=None, label=None, **kwargs):
+        super().__init__(automator=gui.automator, label=label)   
+        self.__root_element_locators = root_element_locators
+        self.__root_element = None
         self._load(*args, **kwargs)
+        self.__parent = gui
+
+    def load_root_element(self):
+        gns_re_locators = None
+        coded_re_locators = None
+        # From GUI Def
+        if self.externalized:
+            gns_re_locators = self.gui_def.root_element_with_locators
+
+        # From constructor. Overrides Gui Def if both places have the def.        
+        if self.__root_element_locators is not None:
+            if type(self.__root_element_locators) not in {list, tuple}:
+                self.__root_element_locators = (self.__root_element_locators,)
+            coded_re_locators = self.__root_element_locators
+
+        self.__root_element_locators = self.__root_element_locators and coded_re_locators or coded_re_locators or gns_re_locators
+
+        from arjuna import Arjuna
+        Arjuna.get_logger().debug("Loaded Root Element for {} widget. Loaded as: {}. Externalized: {}. RE locators in GNS: {}. RE in __init__: {}.".format(
+            self.label,
+            GuiElementMetaData.locators_as_str(self.__root_element_locators),
+            self.externalized,
+            GuiElementMetaData.locators_as_str(gns_re_locators),
+            GuiElementMetaData.locators_as_str(coded_re_locators)
+        ))
+
+        if self.__root_element_locators is not None:
+            self.__root_element = super().element(*self.__root_element_locators)
 
     @property
-    def page(self):
-        return self.__page
+    def root(self):
+        return self.__root_element
+
+    def element(self, *str_or_with_locators, iconfig=None):
+        if self.root:
+            return self.root.element(*str_or_with_locators, iconfig=iconfig)
+        else:
+            return super().element(*str_or_with_locators, iconfig=iconfig)
+
+    def multi_element(self, *str_or_with_locators, iconfig=None):
+        return self.automator.multi_element(self, self.convert_to_with_lmd(*str_or_with_locators), iconfig=iconfig)
+
+    @property
+    def parent(self):
+        return self.__parent
+
+Widget = Section
+Dialog = Section
 
 class App(Gui, metaclass=abc.ABCMeta):
 
@@ -92,7 +138,7 @@ class WebApp(App):
         '''
         super().__init__(config=config, ext_config=ext_config, label=label, gns_dir=gns_dir)
         from arjuna.core.enums import ArjunaOption
-        self.__base_url = base_url is not None and base_url or self.config.get_arjuna_option_value(ArjunaOption.AUT_BASE_URL).as_str()
+        self.__base_url = base_url is not None and base_url or self.config.arjuna_options.value(ArjunaOption.AUT_BASE_URL)
         # self._load(*args, **kwargs)
         self.__args = args
         self.__kwargs = kwargs
@@ -115,10 +161,10 @@ class WebApp(App):
         return getattr(self.ui, name)
 
     def externalize(self, *, gns_dir=None, gns_file_name=None):
-        self.__gns_file_name = gns_file_name is not None and gns_file_name or "{}.gns".format(self.label)        
+        self.__gns_file_name = gns_file_name is not None and gns_file_name or "{}.yaml".format(self.label)        
         from arjuna.core.enums import ArjunaOption   
         self.gns_dir = gns_dir and gns_dir or self.gns_dir
         if not self.gns_dir:
             self.gns_dir = ""
-        print(self.gns_dir, self.__gns_file_name)
-        self.ui.externalize(gns_dir=self.gns_dir, gns_file_name=self.__gns_file_name)
\ No newline at end of file
+        self.ui.externalize(gns_dir=self.gns_dir, gns_file_name=self.__gns_file_name)
+        self._set_externalized()
\ No newline at end of file
