@@ -24,13 +24,15 @@ from enum import Enum, auto
 from abc import abstractmethod
 
 from arjuna.core.enums import GuiAutomationContext
+from arjuna.core.exceptions import GuiLabelNotPresentError
 from arjuna.interact.gui.auto.finder.emd import GuiElementMetaData, Locator, ImplWith
 
 class FileFormat(Enum):
-    GNS = auto()
-    MGNS = auto()
+    # GNS = auto()
+    # MGNS = auto()
     XLS = auto()
     XLSX = auto()
+    YAML = auto()
 
 class GuiNamespaceLoaderFactory:
 
@@ -38,7 +40,7 @@ class GuiNamespaceLoaderFactory:
     @classmethod
     def create_namespace_loader(cls, config, ns_file_path):
         from arjuna.core.enums import ArjunaOption
-        multi_context_enabled = config.get_arjuna_option_value(ArjunaOption.GUIAUTO_DEF_MULTICONTEXT).as_bool()
+        multi_context_enabled = config.arjuna_options.value(ArjunaOption.GUIAUTO_DEF_MULTICONTEXT)
         context = multi_context_enabled and None or config.guiauto_context
         _, file_extension = os.path.splitext(ns_file_path)
         ext = file_extension.upper()[1:]
@@ -53,12 +55,13 @@ class GuiNamespaceLoaderFactory:
                 raise Exception("Namespace file path is a directory and not a file: {}".format(considered_path))
             elif not os.path.isfile(full_file_path):
                 raise Exception("Namespace file path is invalid: {}".format(considered_path))
-
-            if file_format == FileFormat.GNS:
-                if multi_context_enabled:
-                    return MGNSFileLoader(full_file_path)
-                else:
-                    return GNSFileLoader(full_file_path, context)
+            # if file_format == FileFormat.GNS:
+            #     if multi_context_enabled:
+            #         return MGNSFileLoader(full_file_path)
+            #     else:
+            #         return GNSFileLoader(full_file_path, context)
+            if file_format == FileFormat.YAML:
+                return YamlGnsLoader(full_file_path, context)
             else:
                 raise Exception("Unsupported format for namespace: {}".format(file_extension))
 
@@ -88,13 +91,13 @@ class GuiNamespace:
 
     # Needs to be thread-safe
     # Returns emd for a context for a given gui name
-    def get_meta_data(self, name, context):
-        if not self.has(name):
-            raise Exception("Gui namespace >{}< does not contain element with name: {}".format(self.__name, name))
-        elif not self.has_context(name, context):
-            raise Exception("Gui namespace >{}< does not contain element with name: {} for context {}".format(self.__name, name, context))
+    def get_meta_data(self, label, context):
+        if not self.has(label):
+            raise GuiLabelNotPresentError(self.__name, label)
+        elif not self.has_context(label, context):
+            raise GuiLabelNotPresentError(self.__name, label, context)
         
-        return self.__ns[name.lower()][context]
+        return self.__ns[label.lower()][context]
 
 
 class BaseGuiNamespaceLoader:
@@ -124,6 +127,93 @@ class BaseGuiNamespaceLoader:
     def _raise_relativepath_exception(self, file_path):
         raise Exception("Gui namespace loader does not accept relative file path. {} is not a full file path.".format(file_path))
 
+
+class YamlGnsLoader(BaseGuiNamespaceLoader):
+
+    def __init__(self, ns_file_path, context):
+        super().__init__(os.path.basename(ns_file_path))
+        self.__context = context
+        self.__ns_file = None
+        self.__ns_path = None
+
+        #Map<String, Map<GuiAutomationContext,List<Locator>>>
+        self.__ns = {}
+
+        if not os.path.isabs(ns_file_path):
+            super()._raise_relativepath_exception(ns_file_path)
+        elif not os.path.exists(ns_file_path):
+            super()._raise_filenotfound_exception(ns_file_path)
+        elif not os.path.isfile(ns_file_path):
+            super()._raise_notafile_exception(ns_file_path)
+
+        self.__ns_path = ns_file_path
+        self.__ns_file = open(self.__ns_path, "r")
+        self.__contexts = [context]
+
+        self.__withx = None
+
+        # self.__process()
+
+    def load(self):
+
+        from arjuna.configure.impl.validator import ConfigValidator
+        import yaml
+
+        ydict = yaml.load(self.__ns_file, Loader=yaml.SafeLoader)
+
+        if not ydict: return
+
+        sections = list(ydict.keys())
+        lsections = [k.lower() for k in sections]
+
+        if "labels" not in lsections:
+            # print("No labels configured. Skipping...")
+            return
+
+        if "withx" in lsections:
+            self.__withx = {k.lower():v for k,v in ydict[sections[lsections.index("withx")]].items()}
+        else: 
+            self.__withx = dict()
+
+        for label, label_map in ydict[sections[lsections.index("labels")]].items():
+            ConfigValidator.arjuna_name(label)
+            self.__ns[label.lower()] = dict()
+            self.__ns[label.lower()][self.__context] = []
+            for loc, loc_obj in label_map.items():
+                if loc.lower() in self.__withx:
+                    if type(loc_obj) is str:
+                        loc_obj = [loc_obj]
+                    fmt = self.__withx[loc.lower()]
+                    fmt_wtype =  fmt["with_type"].strip().upper()
+                    fmt_value = fmt["with_value"].strip()
+                    with_value = fmt_value.format(*loc_obj)
+                    iloc = ImplWith(wtype=fmt_wtype.upper(), wvalue=with_value, named_args=dict(), has_content_locator=False)
+                    self.__ns[label.lower()][self.__context].append(iloc)
+                else:
+                    iloc = ImplWith(wtype=loc.upper(), wvalue=loc_obj, named_args=dict(), has_content_locator=False)
+                    self.__ns[label.lower()][self.__context].append(iloc)
+            if not self.__ns[label.lower()][self.__context]:
+                raise Exception("No locators defined for label: {}".format(label))
+
+        if "load" in lsections:
+            self.__load_targets = {k.lower():v for k,v in ydict[sections[lsections.index("load")]].items()}        
+
+            if "root" in self.__load_targets:
+                self.__ns["__root__"] = dict()
+                self.__ns["__root__"][self.__context] = list()
+                self.__ns["__root__"][self.__context].extend(self.__ns[self.__load_targets["root"]][self.__context])
+
+            if "anchor" in self.__load_targets:
+                self.__ns["__anchor__"] = dict()
+                self.__ns["__anchor__"][self.__context] = list()
+                self.__ns["__anchor__"][self.__context].extend(self.__ns[self.__load_targets["anchor"]][self.__context])
+
+        for ename, context_data in self.__ns.items():
+            for context, locators in context_data.items():
+                self.add_element_meta_data(ename, context, locators)
+
+'''
+
 class AbstractGNFileLoader(BaseGuiNamespaceLoader):
     NAME_PATTERN = re.compile(r"\[\s*(.*?)\s*\]$")
     LOCATOR_PATTERN = re.compile(r"\s*(.*?)\s*=\s*(.*?)\s*$")
@@ -135,6 +225,7 @@ class AbstractGNFileLoader(BaseGuiNamespaceLoader):
         self.__header_found = False
         self.__last_header = None
         self.__last_auto_contexts = None # list of auto contexts
+        self.__withx = dict()
 
         #Map<String, Map<GuiAutomationContext,List<Locator>>>
         self.__ns = {}
@@ -225,6 +316,7 @@ class AbstractGNFileLoader(BaseGuiNamespaceLoader):
         match = self.NAME_PATTERN.match(input)
         if match:
             current_header = match.group(1)
+
             if self.__is_not_first_header():
                 self.__validate_duplicate_entry(self.last_header, current_header)
                 self.__validate_empty_last_section(self.last_header)
@@ -232,8 +324,9 @@ class AbstractGNFileLoader(BaseGuiNamespaceLoader):
             # Initialise for new section found
             self.last_header = current_header
             self.last_auto_contexts = None
-            from arjuna.configure.impl.validator import ConfigValidator
-            ConfigValidator.arjuna_name(self.last_header)
+            if self.last_header.lower() not in {"__root__", "__state__"}:
+                from arjuna.configure.impl.validator import ConfigValidator
+                ConfigValidator.arjuna_name(self.last_header)
             self.__ns[self.last_header] = {}
             return True
         else:
@@ -329,3 +422,7 @@ class MGNSFileLoader(AbstractGNFileLoader):
             return
         else:
             raise Exception("Unexpected namespace file entry. Namspace content can either be plaforms or identification definition: " + line)
+
+
+# Temp hook. We'll try YAML format with this. Once it works, then we can change the rest.
+'''
\ No newline at end of file
