@@ -125,22 +125,33 @@ class CreateProject(Command):
 
     COMMON_DIRS_FILES = (
         (FileObjectType.DIR, "config"),
+        (FileObjectType.FILE, "config/project.conf"),
         (FileObjectType.DIR, "data"),
-        (FileObjectType.DIR, "data/sources"),
-        (FileObjectType.DIR, "data/references"),
+        (FileObjectType.DIR, "data/source"),
+        (FileObjectType.DIR, "data/reference"),
+        (FileObjectType.DIR, "data/reference/excel_column"),
+        (FileObjectType.DIR, "data/reference/excel_row"),
+        (FileObjectType.DIR, "data/l10"),
+        (FileObjectType.DIR, "data/l10/excel"),
         (FileObjectType.DIR, "guiauto"),
-        (FileObjectType.DIR, "guiauto/drivers"),
-        (FileObjectType.DIR, "guiauto/drivers/linux"),
-        (FileObjectType.DIR, "guiauto/drivers/mac"),
-        (FileObjectType.DIR, "guiauto/drivers/windows"),
-        (FileObjectType.DIR, "guiauto/images"),
+        (FileObjectType.DIR, "guiauto/driver"),
+        (FileObjectType.DIR, "guiauto/driver/linux"),
+        (FileObjectType.DIR, "guiauto/driver/mac"),
+        (FileObjectType.DIR, "guiauto/driver/windows"),
         (FileObjectType.DIR, "guiauto/namespace"),
         (FileObjectType.DIR, "report"),
-        (FileObjectType.FILE, "config/project.conf"),
-        (FileObjectType.DIR, "tests"),
-        (FileObjectType.DIR, "tests/modules"),
-        (FileObjectType.FILE, "tests/__init__.py"),
-        (FileObjectType.FILE, "tests/modules/__init__.py"),
+        (FileObjectType.DIR, "script"),
+        (FileObjectType.DIR, "test"),
+        (FileObjectType.FILE, "test/__init__.py"),
+        (FileObjectType.DIR, "test/module"),
+        (FileObjectType.FILE, "test/module/__init__.py"),
+        (FileObjectType.DIR, "lib"),
+        (FileObjectType.FILE, "lib/__init__.py"),
+        (FileObjectType.DIR, "lib/fixture"),
+        (FileObjectType.FILE, "lib/fixture/__init__.py"),
+        (FileObjectType.FILE, "lib/fixture/session.py"),
+        (FileObjectType.FILE, "lib/fixture/module.py"),
+        (FileObjectType.FILE, "lib/fixture/test.py"),
     )
 
     def __init__(self, subparsers, parents):
@@ -157,10 +168,20 @@ class CreateProject(Command):
             f.close()
 
     def execute(self, arg_dict):
+        def get_src_file_path(src):
+            return os.path.join(os.path.dirname(os.path.realpath(__file__)), src)
+
+        def get_proj_target_path(dest):
+            return os.path.join(project_temp_dir, dest)
+
+        def copy_file(src, dest):
+            shutil.copyfile(get_src_file_path(src), get_proj_target_path(dest))
+
         for parent in self.parents:
             parent.process(arg_dict)
         # from arjuna import ArjunaCore
         pdir = arg_dict['project.root.dir']
+        print(os.path.join(pdir, "config/project.conf"))
         if os.path.exists(os.path.join(pdir, "config/project.conf")):
             print("Arjuna project already exists at the specified location.")
             sys.exit(1)
@@ -171,10 +192,18 @@ class CreateProject(Command):
             os.makedirs(project_temp_dir)
             for ftype, frpath in CreateProject.COMMON_DIRS_FILES:
                 self.__create_file_or_dir(project_temp_dir, ftype, frpath)
-            shutil.copyfile(
-                os.path.join(os.path.dirname(os.path.realpath(__file__)), "../../res/scripts/arjuna_launcher.py"),
-                os.path.join(project_temp_dir, "arjuna_launcher.py")
-                )
+            copy_file("../../res/proj.conf", "config/project.conf")
+            copy_file("../../res/scripts/arjuna_launcher.py", "script/arjuna_launcher.py")
+            f = open(get_src_file_path("../../res/conftest.txt"), "r")
+            contents = f.read().format(project=project_name)
+            f.close()
+            f = open(get_proj_target_path("test/conftest.py"), "w")
+            f.write(contents)
+            f.close()
+            for d in [ "data/source", "data/l10/excel", "data/reference/excel_row", "data/reference/excel_column", "guiauto/namespace"]:
+                copy_file("../../res/placeholder.txt", d + "/placeholder.txt")
+            for os_name in ["mac", "windows", "linux"]:
+                copy_file("../../res/placeholder.txt", "guiauto/driver/{}/driver.txt".format(os_name))
             for f in os.listdir(project_temp_dir):
                 try:
                     shutil.move(os.path.join(project_temp_dir, f), pdir)
@@ -202,15 +231,15 @@ class __RunCommand(Command):
         project_root_dir = arg_dict.pop("project.root.dir")
         runid = arg_dict.pop("run.id")
         static_rid = arg_dict.pop("static.rid")
-        self.enumerate_only = arg_dict.pop("enumerate")
+        self.dry_run = arg_dict.pop("dry_run")
 
         Arjuna.init(project_root_dir, CliArgsConfig(arg_dict).as_map(), runid, static_rid=static_rid)
 
         import sys
-        proj_dir = Arjuna.get_ref_config().get_arjuna_option_value(ArjunaOption.PROJECT_ROOT_DIR).as_str()
+        proj_dir = Arjuna.get_ref_config().arjuna_options.value(ArjunaOption.PROJECT_ROOT_DIR)
         sys.path.append(proj_dir + "/..")
 
-        py_3rdparty_dir = Arjuna.get_ref_config().get_arjuna_option_value(ArjunaOption.ARJUNA_EXTERNAL_IMPORTS_DIR).as_str()
+        py_3rdparty_dir = Arjuna.get_ref_config().arjuna_options.value(ArjunaOption.ARJUNA_EXTERNAL_IMPORTS_DIR)
         sys.path.append(py_3rdparty_dir)
 
 
@@ -223,8 +252,7 @@ class RunProject(__RunCommand):
         from arjuna.engine.runner import TestRunner
         test_runner = TestRunner()
         test_runner.load_all_tests()
-        test_runner.run(only_enumerate=self.enumerate_only)
-
+        test_runner.run(dry_run=self.dry_run)
 
 class RunSelected(__RunCommand):
 
@@ -234,12 +262,12 @@ class RunSelected(__RunCommand):
     def execute(self, arg_dict):
         pickers_dict = dict()
         pickers = (
-            ('cmodules', 'cm'),
             ('imodules', 'im'),
+            ('emodules', 'em'),
             # ('cclasses', 'cc'),
             # ('iclasses', 'ic'),
-            ('ctests', 'ct'),
             ('itests', 'it'),
+            ('etests', 'et'),
             )
 
         def process_picker(sname, tname):
@@ -252,22 +280,22 @@ class RunSelected(__RunCommand):
             else:
                 pickers_dict[tname] = list()
 
-        def add_py_ext(name):
+        def remove_py_ext(name):
             if not name.lower().endswith(".py"):
-                return name + ".py"
-            else:
                 return name
+            else:
+                return name.replace(".py","")
 
         for picker in pickers:
             process_picker(picker[0], picker[1])
 
-        pickers_dict['cm'] = [add_py_ext(m) for m in pickers_dict['cm']]
-        pickers_dict['im'] = [add_py_ext(m) for m in pickers_dict['im']]
+        pickers_dict['im'] = [remove_py_ext(m) for m in pickers_dict['im']]
+        pickers_dict['em'] = [remove_py_ext(m) for m in pickers_dict['em']]
 
         super().execute(arg_dict)
 
         from arjuna.engine.runner import TestRunner
         test_runner = TestRunner()
         test_runner.load_tests_from_pickers(**pickers_dict)
-        test_runner.run(only_enumerate=self.enumerate_only)
+        test_runner.run(dry_run=self.dry_run)
 
